@@ -10,8 +10,8 @@ CONFIG = {
         'class_': oauth1.Twitter,
         
         # Twitter is an AuthorizationProvider so we need to set several other properties too:
-        'consumer_key': 'zku3BZ9wi7e4e07h0M3VA',
-        'consumer_secret': 'WQ0SYSUWXlBiLvYAJ32DDMfwsJ4up79EfifNXks',
+        'consumer_key': '########################',
+        'consumer_secret': '########################',
     },
     
     'fb': {
