@@ -23,7 +23,7 @@ CONFIG = {
         'consumer_secret': '7163e6e8dedc2c055445b553823ec910',
         
         # But it is also an OAuth 2.0 provider and it needs scope.
-        'scope': ['user_about_me', 'email', 'publish_stream'],
+        'scope': ['user_about_me', 'email', 'publish_stream', 'read_stream'],
     },
     
     'gae_oi': {
@@ -36,7 +36,8 @@ CONFIG = {
     
     'oi': {
            
-        # OpenID provider dependent on the python-openid package.
+        # OpenID provider based on the python-openid library.
+        # Works everywhere, is flexible, but requires more resources.
         'class_': openid.OpenID,
     }
-}
\ No newline at end of file
+}
