@@ -7,7 +7,6 @@ import constants
 
 # Choose and configure the browser of your choice
 def get_browser():
-    return webdriver.Firefox()
     return webdriver.Chrome()
 
 # The host and port where the tested ap shoud listen.
@@ -24,23 +23,24 @@ HOST_ALIAS = 'authomatic.com'
 # This is a convenience to easily exclude providers from tests by commenting
 # them out.
 INCLUDE_PROVIDERS = [
-    'behance',
-    'bitbucket',
-    'bitly',
+    'amazon',
+    'bitly', # 5
     'deviantart',
+    'eventbrite', # 4
     'facebook',
-    'foursquare',
+    'foursquare', # 1
     'google',
-    'github',
+    'github', # 3
     'linkedin',
     'paypal',
-    'reddit',
+    'reddit', # 2
     'vk',
     'windowslive',
     'yammer',
     'yandex',
 ]
 
+
 # Use these constants if you have the same user info by all tested providers.
 PASSWORD = '1Kokotina'
 EMAIL = 'peterhudec@peterhudec.com'
@@ -99,6 +99,12 @@ COMMON = {
 # Values from COMMON will be overriden by values from PROVIDERS[provider_name]
 # if set.
 PROVIDERS = {
+    'amazon': {
+        'consumer_key': 'amzn1.application-oa2-client.aac94a29737c4d86a734e5964696d2bd',
+        'consumer_secret': 'bb1aa3772cd755d009ba419211fccde1e785021e1bbea4334235ca298dac42b0',
+        'user_id': 'amzn1.account.AFQXBE5AJMX73ZABIBYD25ET2MZQ',
+        'user_password': 'Ebencikrista4krat',
+    },
     'behance': {
         'consumer_key': 'J6MwhGHdTHwwYQEHyTq2jNgly0EEXixe',
         'consumer_secret': 'A3IP7wH2pZ0zpiCCCYwO.Z7HkK',
@@ -113,13 +119,18 @@ PROVIDERS = {
         'consumer_key': '376',
         'consumer_secret': 'd56ec842a9558fe9916210b376988c2d',
     },
+    'eventbrite': {
+        'consumer_key': 'M5T4QRF5TNIQQJ76EC',
+        'consumer_secret': 'C4HNTPVUKCMK3XBWQJ45KFV5H2AIII5C7XNNPZIYSQIQAPMQP7',
+        'user_id': '125996068589',
+    },
     'facebook': {
         'consumer_key': '482771598445314',
         'consumer_secret': '7163e6e8dedc2c055445b553823ec910',
         'user_id': '737583375',
         'user_password': 'kokotina',
         # This changes when switching from and to Daylight Saving Time
-        'user_timezone': '2',
+        # 'user_timezone': '2',
     },
     'foursquare': {
         'consumer_key': '11Q4GU3IGQYN3QTR5542VAGE1ZCQD5QDAOXVR1LA3FZ3Q24Z',
@@ -139,8 +150,8 @@ PROVIDERS = {
                          'AAAAAAAAAAI/AAAAAAAAOWY/3rWutUjFRGw/photo.jpg?sz=50'),
     },
     'github': {
-        'consumer_key': 'c6626326556058c8b4e6',
-        'consumer_secret': '10a414828680701bd4005d3f67510e1d8864c3dd',
+        'consumer_key': '4dde1fd8f548bfe87f0c',
+        'consumer_secret': '6549d450d58f1285fe82cf7a0f1c1dd4316a6644',
         'user_id': '2333157',
         'access_headers': {'User-Agent': ('Authomatic.py Automated Functional '
                                           'Tests')},
@@ -159,8 +170,8 @@ PROVIDERS = {
         'consumer_secret': 'EJqCvRAZ4sFobX_NlzyVMyD3PSXH41pAWpeCFpiepworglq_f_5dl3TrCYFl',
     },
     'reddit': {
-        'consumer_key': 'sodaC5hCCS-QHA',
-        'consumer_secret': 'zBevflb04ncHRYbbG8ZAfQoy9T8',
+        'consumer_key': 'Jx3WyR5xS4pm1A',
+        'consumer_secret': 'Z0RWV65T5e-qKf0OHDIu1baKhrI',
         'user_login': USERNAME,
         'user_id': 'aurmu',
         'access_headers': {'User-Agent': ('Authomatic.py Automated Functional '
